@@ -1,4 +1,6 @@
+#!/usr/bin/python
 import ast
+import os
 
 class PREFS(object):
     """docstring for PREFS"""
@@ -29,9 +31,9 @@ class PREFS(object):
                 for line in lines:
                     #print(line)
                     if not self.interprete:
-                        content[line.split(self.separator)[0]] = line.split(self.separator)[1]
+                        content[line.split(self.separator, 1)[0]] = line.split(self.separator, 1)[1]
                     elif self.interprete:
-                        content[line.split(self.separator)[0]] = ast.literal_eval(line.split(self.separator)[1])
+                        content[line.split(self.separator, 1)[0]] = ast.literal_eval(line.split(self.separator, 1)[1])
 
             elif len(lines) == 1:
                 line = lines[0].split(self.ender)
@@ -39,9 +41,9 @@ class PREFS(object):
                 for i in line:
 
                     if not self.interprete:
-                        content[i.split(self.separator)[0]] = i.split(self.separator)[1]
+                        content[i.split(self.separator, 1)[0]] = i.split(self.separator, 1)[1]
                     elif self.interprete:
-                        content[i.split(self.separator)[0]] = ast.literal_eval(i.split(self.separator)[1])
+                        content[i.split(self.separator, 1)[0]] = ast.literal_eval(i.split(self.separator, 1)[1])
 
             #print(content)
             prefsTXT.close()
@@ -53,9 +55,9 @@ class PREFS(object):
             except TypeError:
                 self.CreatePrefs(self.prefs)
 
-    def CreatePrefs(self, prefsDictionarie):
+    def CreatePrefs(self, prefs):
         prefsTXT = open(f"{self.filename}.txt","w+")
-        for i in prefsDictionarie.items():
+        for i in prefs.items():
             prefsTXT.write(f"{i[0]}={i[1]}{self.ender}")
 
         prefsTXT.close()
@@ -72,4 +74,18 @@ class PREFS(object):
 
         prefsTXT = open(f"{self.filename}.txt","w+")
         prefsTXT.write(text)
-        prefsTXT.close()
\ No newline at end of file
+        prefsTXT.close()
+
+        self.ReadPrefs()
+
+    def ReWritePrefs(self, prefs):
+        if os.path.exists(f"{self.filename}.txt"):
+            os.remove(f"{self.filename}.txt")
+            self.CreatePrefs(prefs)
+
+        self.ReadPrefs()
+            
+    def ChangeFilename(self, filename):
+        self.filename = filename
+
+        self.ReadPrefs()
\ No newline at end of file
